==> haskell-crypto-api-tests-0.3-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api-tests
version: 0.3
id: crypto-api-tests-0.3-Kk0hixfahmk4RM8oY9rRU9
key: crypto-api-tests-0.3-Kk0hixfahmk4RM8oY9rRU9
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: http://trac.haskell.org/crypto-api/wiki
synopsis: A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).
category: Data, Cryptography
abi: 45c0ccb6254f0e63c12f30dbb091755b
exposed: True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish
hidden-modules: Paths_crypto_api_tests
import-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-api-tests-0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/crypto-api-tests-0.3
hs-libraries: HScrypto-api-tests-0.3-Kk0hixfahmk4RM8oY9rRU9
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.13.1-BED53w0KTtOAjBW8qj2Yxi base-4.12.0.0
    bytestring-0.10.8.2 cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    crypto-api-0.13.3-ALzE3By8BvHGVvnn2irh7V directory-1.3.3.0
    filepath-1.4.2.1 test-framework-0.8.2.0-DQsV9kQVQbN9pqcWwfJelK
    test-framework-hunit-0.3.0.2-B9JXp9boQOT1pHZweIRSGN
    test-framework-quickcheck2-0.3.0.5-I1goVSS4GnaKUoWxDAV0lq
haddock-interfaces: /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock
haddock-html: /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-api-tests-0.3-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api-tests
version: 0.3
id: crypto-api-tests-0.3-AKRaINuWyiAE9cZgsCAIav
key: crypto-api-tests-0.3-AKRaINuWyiAE9cZgsCAIav
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: http://trac.haskell.org/crypto-api/wiki
synopsis: A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).
category: Data, Cryptography
abi: a710a1a6af4d78438d8a8be4a6ca14c7
exposed: True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish
hidden-modules: Paths_crypto_api_tests
import-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-api-tests-0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/crypto-api-tests-0.3
hs-libraries: HScrypto-api-tests-0.3-AKRaINuWyiAE9cZgsCAIav
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.13.1-7krqagqcRmA9RWDtUhyOg8 base-4.12.0.0
    bytestring-0.10.8.2 cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    crypto-api-0.13.3-ALzE3By8BvHGVvnn2irh7V directory-1.3.3.0
    filepath-1.4.2.1 test-framework-0.8.2.0-2dhLXXIyuWjLumyCVFTYFd
    test-framework-hunit-0.3.0.2-AUvDMODuuEQ5DvQ81J8cMW
    test-framework-quickcheck2-0.3.0.5-H6NFUqKUfdG3eXRRFkZww5
haddock-interfaces: /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock
haddock-html: /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
